==> totoui-0.3.0.tgz: package/lib/badge.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var Badge = (function (_React$Component) {
    _inherits(Badge, _React$Component);

    function Badge(props) {
        _classCallCheck(this, Badge);

        _get(Object.getPrototypeOf(Badge.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderAnchor = this.renderAnchor.bind(this);
    }

    _createClass(Badge, [{
        key: 'renderAnchor',
        value: function renderAnchor(classSet) {
            var Component = this.props.componentTag || 'a';
            var href = this.props.href || '#';

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    href: href,
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    role: "badge" }),
                this.props.children
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();
            var Component = this.props.componentTag;
            var renderAnchor = this.props.href;

            if (renderAnchor) {
                return this.renderAnchor(classSet);
            }

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                this.props.children
            );
        }
    }]);

    return Badge;
})(_react2['default'].Component);

Badge.displayName = "Badge";

Badge.propTypes = {
    componentTag: _react2['default'].PropTypes.node,
    href: _react2['default'].PropTypes.string,
    round: _react2['default'].PropTypes.bool,
    radius: _react2['default'].PropTypes.bool
};

Badge.defaultProps = {
    classPrefix: 'badge',
    componentTag: 'span'
};

module.exports = Badge;

==> totoui-0.5.1.tgz: package/lib/badge.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var Badge = (function (_React$Component) {
    _inherits(Badge, _React$Component);

    function Badge(props) {
        _classCallCheck(this, Badge);

        _get(Object.getPrototypeOf(Badge.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderAnchor = this.renderAnchor.bind(this);
    }

    _createClass(Badge, [{
        key: 'renderAnchor',
        value: function renderAnchor(classSet) {
            var Component = this.props.componentTag || 'a';
            var href = this.props.href || '#';

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    href: href,
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    role: 'badge' }),
                this.props.children
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();
            var Component = this.props.componentTag;
            var renderAnchor = this.props.href;

            if (renderAnchor) {
                return this.renderAnchor(classSet);
            }

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                this.props.children
            );
        }
    }]);

    return Badge;
})(_react2['default'].Component);

Badge.displayName = "Badge";

Badge.propTypes = {
    componentTag: _react2['default'].PropTypes.node,
    href: _react2['default'].PropTypes.string,
    round: _react2['default'].PropTypes.bool,
    radius: _react2['default'].PropTypes.bool
};

Badge.defaultProps = {
    classPrefix: 'badge',
    componentTag: 'span'
};

module.exports = Badge;
